@@ -22,7 +22,7 @@
 #' @param nnLocfit A numeric value defining the constant component of the
 #' smoothing parameter nn (see Details).
 #'
-#' @return An object of class singleOut, a \code{data.frame} with the following
+#' @returns An object of class singleOut, a \code{data.frame} with the following
 #' columns.
 #' \describe{
 #'   \item{plotId}{plotId}
@@ -174,7 +174,7 @@ detectSingleOut <- function(TP,
 #' @param ... Ignored.
 #' @param outOnly Should only plots containing outliers be plotted?
 #'
-#' @return A list of ggplot objects is invisibly returned.
+#' @returns A list of ggplot objects is invisibly returned.
 #'
 #' @examples
 #' ## Create a TP object containing the data from the Phenovator.
@@ -258,16 +258,7 @@ plot.singleOut <- function(x,
   if (nPlots >= 25) {
     ## More than 25 plots.
     ## For identical layout on all pages use 5 x 5 plots throughout.
-    #rowPag <- colPag <- rep(x = 5, times = nPag)
-
-    # 28-7-2020. ggforce has a bug that prevents this identical layout
-    # https://github.com/thomasp85/ggforce/issues/201
-    # When fixed the code above can be reactivated and the three lines below
-    # removed.
-    plotsLastPag <- nPlots %% 25
-    rowPag <- c(rep(x = 5, times = nPag - 1), min(plotsLastPag %/% 5 + 1, 5))
-    colPag <- c(rep(x = 5, times = nPag - 1),
-                ifelse(plotsLastPag >= 5, 5, plotsLastPag))
+    rowPag <- colPag <- rep(x = 5, times = nPag)
   } else {
     ## Less than 25 plots.
     ## Fill page by row of 5 plots.
@@ -301,7 +292,7 @@ plot.singleOut <- function(x,
 #' @param trait The trait that should be set to NA. Can be ignored when using
 #' the output of \code{detectSingleOut} as input.
 #'
-#' @return An object of class TP, the input with the outlier replaced by NA.
+#' @returns An object of class TP, the input with the outlier replaced by NA.
 #'
 #' @examples
 #' ## Create a TP object containing the data from the Phenovator.
